Colour Quality
==============

Colour Fidelity Index
---------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    COLOUR_FIDELITY_INDEX_METHODS
    colour_fidelity_index

``colour.quality``

.. currentmodule:: colour.quality

.. autosummary::
    :toctree: generated/

    ColourRendering_Specification_CIE2017
    colour_fidelity_index_CIE2017
    ColourQuality_Specification_ANSIIESTM3018
    colour_fidelity_index_ANSIIESTM3018

Colour Rendering Index
----------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    colour_rendering_index

``colour.quality``

.. currentmodule:: colour.quality

.. autosummary::
    :toctree: generated/

    ColourRendering_Specification_CRI

Colour Quality Scale
--------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    COLOUR_QUALITY_SCALE_METHODS
    colour_quality_scale

``colour.quality``

.. currentmodule:: colour.quality

.. autosummary::
    :toctree: generated/

    ColourRendering_Specification_CQS

Academy Spectral Similarity Index (SSI)
---------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    spectral_similarity_index
